/*

  Can Bus MCP2515 (Transiver)

  Parts required:
  - Arduino Board
  - Can Bus MCP2515

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 15 Sep 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <SPI.h>                              // include library SPI
#include <mcp2515.h>                          // include library mcp2515

struct can_frame canMsg;
MCP2515 mcp2515(10);                          // set the pin number where SPI CS is connected (10 by default)

void setup() {
  Serial.begin(9600);                         // start Serial Communication
  SPI.begin();                                // start SPI
  mcp2515.reset();                            // reset Can Bus MCP2515
  mcp2515.setBitrate(CAN_50KBPS, MCP_8MHZ);   // set bit rate to 50KBps and internal clock to 8MHz
  mcp2515.setNormalMode();                    // set mode
  Serial.println("MCP Startet....");          // print text to Serial Monitor
  randomSeed(analogRead(0));                  // set randomSeed to analog port 0 for real random numbers
}

void loop() {
  int randomNumbers;                            // set variable randomNumber

  canMsg.can_id = 0x036;                        // CAN id as 0x036
  canMsg.can_dlc = 8;                           // CAN data length as 8

  for (int counter = 0; counter <= 7; counter++) {
    randomNumbers = random(255);                  // set randomNumbers as a number between 0 and 255
    canMsg.data[counter] = randomNumbers;               // Update dataToSend
  }
  mcp2515.sendMessage(&canMsg);                 //Sends the CAN message
  delay(1000);                                // wait 1000ms
}
