/*

  Can Bus MCP2515 (Transiver)

  Parts required:
  - Arduino Board
  - Can Bus MCP2515

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 10 Sep 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <SPI.h>                              // include library SPI
#include <mcp2515.h>                          // include library mcp2515

struct can_frame canMsg;
MCP2515 mcp2515(10);                          // Set the pin number where SPI CS is connected (10 by default)
int dataToSend = 5;                           // set variable dataToSend as 5 

void setup(){
  Serial.begin(9600);                         // start Serial Communication
  SPI.begin();                                // start SPI
  mcp2515.reset();                            // reset Can Bus MCP2515
  mcp2515.setBitrate(CAN_50KBPS, MCP_8MHZ);   // set bit rate to 50KBps and internal clock to 8MHz
  mcp2515.setNormalMode();                    // set mode
  Serial.println("MCP Startet....");          // print text to Serial Monitor
}

void loop(){
  canMsg.can_id = 0x036;                      // CAN id as 0x036    
  canMsg.can_dlc = 8;                         // CAN data length as 8
  canMsg.data[0] = dataToSend;                // Update dataToSend
  canMsg.data[1] = 0x00;                      // Send rest of the data as 0
  canMsg.data[2] = 0x00;
  canMsg.data[3] = 0x00;
  canMsg.data[4] = 0x00;
  canMsg.data[5] = 0x00;
  canMsg.data[6] = 0x00;
  canMsg.data[7] = 0x00;
  mcp2515.sendMessage(&canMsg);               //Sends the CAN message
  Serial.print("Data send : ");               // print text to Serial Monitor
  Serial.println(dataToSend);                 // print dataToSend variable to Serial Monitor
  Serial.print("");                           // print new line
  delay(1000);                                // wait 1000ms
}
